==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/ReplicationRuleFilter.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Prefix
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ReplicationRuleFilter(
    prefix: Optional[Prefix] = Optional.Absent,
    tag: Optional[zio.aws.s3.model.Tag] = Optional.Absent,
    and: Optional[zio.aws.s3.model.ReplicationRuleAndOperator] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationRuleFilter = {
    import ReplicationRuleFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
      .builder()
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(tag.map(value => value.buildAwsValue()))(_.tag)
      .optionallyWith(and.map(value => value.buildAwsValue()))(_.and)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationRuleFilter.ReadOnly =
    zio.aws.s3.model.ReplicationRuleFilter.wrap(buildAwsValue())
}
object ReplicationRuleFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationRuleFilter =
      zio.aws.s3.model.ReplicationRuleFilter(
        prefix.map(value => value),
        tag.map(value => value.asEditable),
        and.map(value => value.asEditable)
      )
    def prefix: Optional[Prefix]
    def tag: Optional[zio.aws.s3.model.Tag.ReadOnly]
    def and: Optional[zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly]
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getTag: ZIO[Any, AwsError, zio.aws.s3.model.Tag.ReadOnly] =
      AwsError.unwrapOptionField("tag", tag)
    def getAnd: ZIO[
      Any,
      AwsError,
      zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly
    ] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ) extends zio.aws.s3.model.ReplicationRuleFilter.ReadOnly {
    override val prefix: Optional[Prefix] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.s3.model.primitives.Prefix(value))
    override val tag: Optional[zio.aws.s3.model.Tag.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tag())
        .map(value => zio.aws.s3.model.Tag.wrap(value))
    override val and
        : Optional[zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.and())
        .map(value => zio.aws.s3.model.ReplicationRuleAndOperator.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ): zio.aws.s3.model.ReplicationRuleFilter.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/ReplicationRuleFilter.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Prefix
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ReplicationRuleFilter(
    prefix: Option[Prefix] = None,
    tag: Option[zio.aws.s3.model.Tag] = None,
    and: Option[zio.aws.s3.model.ReplicationRuleAndOperator] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationRuleFilter = {
    import ReplicationRuleFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
      .builder()
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(tag.map(value => value.buildAwsValue()))(_.tag)
      .optionallyWith(and.map(value => value.buildAwsValue()))(_.and)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationRuleFilter.ReadOnly =
    zio.aws.s3.model.ReplicationRuleFilter.wrap(buildAwsValue())
}
object ReplicationRuleFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationRuleFilter =
      zio.aws.s3.model.ReplicationRuleFilter(
        prefix.map(value => value),
        tag.map(value => value.asEditable),
        and.map(value => value.asEditable)
      )
    def prefix: Option[Prefix]
    def tag: Option[zio.aws.s3.model.Tag.ReadOnly]
    def and: Option[zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly]
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getTag: ZIO[Any, AwsError, zio.aws.s3.model.Tag.ReadOnly] =
      AwsError.unwrapOptionField("tag", tag)
    def getAnd: ZIO[
      Any,
      AwsError,
      zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly
    ] = AwsError.unwrapOptionField("and", and)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ) extends zio.aws.s3.model.ReplicationRuleFilter.ReadOnly {
    override val prefix: Option[Prefix] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.s3.model.primitives.Prefix(value))
    override val tag: Option[zio.aws.s3.model.Tag.ReadOnly] =
      scala.Option(impl.tag()).map(value => zio.aws.s3.model.Tag.wrap(value))
    override val and
        : Option[zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly] = scala
      .Option(impl.and())
      .map(value => zio.aws.s3.model.ReplicationRuleAndOperator.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleFilter
  ): zio.aws.s3.model.ReplicationRuleFilter.ReadOnly = new Wrapper(impl)
}
